@@ -34,14 +34,9 @@ class Regbot:
   @classmethod
   def buySignalGenerator(cls,opening,closing,volume):
     scalledInput = cls.prepareInput(opening,closing,volume)
-    return cls.loadmodel().predict(scalledInput)[0].round() #[0:,1] > alpha).astype("int32")[0]
-    
-  '''
-  @classmethod
-  def sellSignalGenerator(cls,opening,closing,volume):
-    scalledInput = cls.prepareInput(opening,closing,volume)
-    return cls.loadmodel().predict(scalledInput).round() #[0:,0] > alpha).astype("int32")[0]
-  '''
+    return cls.loadmodel().predict(scalledInput)[0].round()
+
+
 
 
 def signal(opening,closing,volume):
